@@ -12,16 +12,23 @@ that can be passed.
 # pylint: disable=invalid-name
 
 import math
-from typing import Union
 import numpy as np
-from spatialmath.base import symbolic as sym
+
+# from spatialmath.base import symbolic as sym # HACK
+from spatialmath.base.symbolic import issymbol, symtype
 
 # valid scalar types
-_scalartypes = (int, np.integer, float, np.floating) + sym.symtype
+_scalartypes = (int, np.integer, float, np.floating) + symtype
 
-ArrayLike = Union[list, np.ndarray, tuple, set]
+# from typing import Union, List, Tuple, Any, Optional, Type, Callable
+# from numpy.typing import DTypeLike
+# Array = np.ndarray[Any, np.dtype[np.floating]]
+# ArrayLike = Union[float,List[float],Tuple,Array]  # various ways to represent R^3 for input
 
-def isscalar(x):
+from spatialmath.base.types import *
+
+
+def isscalar(x: Any) -> bool:
     """
     Test if argument is a real scalar
 
@@ -42,7 +49,7 @@ def isscalar(x):
     return isinstance(x, _scalartypes)
 
 
-def isinteger(x):
+def isinteger(x: Any) -> bool:
     """
     Test if argument is a scalar integer
 
@@ -62,7 +69,9 @@ def isinteger(x):
     return isinstance(x, (int, np.integer))
 
 
-def assertmatrix(m, shape=None):
+def assertmatrix(
+    m: Any, shape: Tuple[Union[int, None], Union[int, None]] = (None, None)
+) -> None:
     """
     Assert that argument is a 2D matrix
 
@@ -116,11 +125,13 @@ def assertmatrix(m, shape=None):
             )
 
 
-def ismatrix(m, shape):
+def ismatrix(m: Any, shape: Tuple[Union[int, None], Union[int, None]]) -> bool:
     """
     Test if argument is a real 2D matrix
 
-    :param m: value to test :param shape: required shape :type shape: 2-tuple
+    :param m: value to test
+    :param shape: required shape
+    :type shape: 2-tuple
     :return: True if value is of specified shape :rtype: bool
 
     Tests if the argument is a real 2D matrix with a specified shape ``shape``
@@ -155,7 +166,11 @@ def ismatrix(m, shape):
     return True
 
 
-def getmatrix(m, shape, dtype=np.float64):
+def getmatrix(
+    m: ArrayLike,
+    shape: Tuple[Union[int, None], Union[int, None]],
+    dtype: DTypeLike = np.float64,
+) -> np.ndarray:
     r"""
     Convert argument to 2D array
 
@@ -213,8 +228,9 @@ def getmatrix(m, shape, dtype=np.float64):
 
     elif isvector(m):
         # passed a 1D array
-        m = getvector(m, dtype=dtype)
+        m = getvector(m, dtype=dtype, out="array")
         if shape[0] is not None and shape[1] is not None:
+            shape = cast(Tuple[int, int], shape)
             if len(m) == np.prod(shape):
                 return m.reshape(shape)
             else:
@@ -230,7 +246,9 @@ def getmatrix(m, shape, dtype=np.float64):
         raise TypeError("argument must be scalar or ndarray")
 
 
-def verifymatrix(m, shape):
+def verifymatrix(
+    m: np.ndarray, shape: Tuple[Union[int, None], Union[int, None]]
+) -> None:
     """
     Assert that argument is array of specified size
 
@@ -252,13 +270,58 @@ def verifymatrix(m, shape):
         raise TypeError("input must be a numPy ndarray")
 
     if not m.shape == shape:
-        raise ValueError("incorrect matrix dimensions, " "expecting {0}".format(shape))
+        raise ValueError("incorrect matrix dimensions, expecting {0}".format(shape))
 
 
 # and not np.iscomplex(m) checks every element, would need to be not np.any(np.iscomplex(m)) which seems expensive
 
 
-def getvector(v, dim=None, out="array", dtype=np.float64) -> ArrayLike:
+@overload
+def getvector(
+    v: ArrayLike,
+    dim: Optional[Union[int, None]] = None,
+    out: str = "array",
+    dtype: DTypeLike = np.float64,
+) -> NDArray:
+    ...
+
+
+@overload
+def getvector(
+    v: ArrayLike,
+    dim: Optional[Union[int, None]] = None,
+    out: str = "list",
+    dtype: DTypeLike = np.float64,
+) -> List[float]:
+    ...
+
+
+@overload
+def getvector(
+    v: Tuple[float, ...],
+    dim: Optional[Union[int, None]] = None,
+    out: str = "sequence",
+    dtype: DTypeLike = np.float64,
+) -> Tuple[float, ...]:
+    ...
+
+
+@overload
+def getvector(
+    v: List[float],
+    dim: Optional[Union[int, None]] = None,
+    out: str = "sequence",
+    dtype: DTypeLike = np.float64,
+) -> List[float]:
+    ...
+
+
+def getvector(
+    v: ArrayLike,
+    dim: Optional[Union[int, None]] = None,
+    out: str = "array",
+    dtype: DTypeLike = np.float64,
+) -> Union[NDArray, List[float], Tuple[float, ...]]:
     """
     Return a vector value
 
@@ -321,16 +384,17 @@ def getvector(v, dim=None, out="array", dtype=np.float64) -> ArrayLike:
     dt = dtype
 
     if isinstance(v, _scalartypes):  # handle scalar case
-        v = [v]
-
+        v = [v]  # type: ignore
     if isinstance(v, (list, tuple)):
         # list or tuple was passed in
 
-        if sym.issymbol(v):
+        if issymbol(v):
             dt = None
 
         if dim is not None and v and len(v) != dim:
-            raise ValueError("incorrect vector length")
+            raise ValueError(
+                "incorrect vector length: expected {}, got {}".format(dim, len(v))
+            )
         if out == "sequence":
             return v
         elif out == "list":
@@ -371,7 +435,9 @@ def getvector(v, dim=None, out="array", dtype=np.float64) -> ArrayLike:
         raise TypeError("invalid input type")
 
 
-def assertvector(v, dim, msg=None):
+def assertvector(
+    v: Any, dim: Optional[Union[int, None]] = None, msg: Optional[str] = None
+) -> None:
     """
     Assert that argument is a real vector
 
@@ -397,7 +463,7 @@ def assertvector(v, dim, msg=None):
         raise ValueError(msg)
 
 
-def isvector(v, dim=None):
+def isvector(v: Any, dim: Optional[int] = None) -> bool:
     """
     Test if argument is a real vector
 
@@ -453,7 +519,29 @@ def isvector(v, dim=None):
     return False
 
 
-def getunit(v, unit="rad") -> ArrayLike:
+@overload
+def getunit(v: float, unit: str = "rad") -> float:  # pragma: no cover
+    ...
+
+
+@overload
+def getunit(v: NDArray, unit: str = "rad") -> NDArray:  # pragma: no cover
+    ...
+
+
+@overload
+def getunit(v: List[float], unit: str = "rad") -> List[float]:  # pragma: no cover
+    ...
+
+
+@overload
+def getunit(v: Tuple[float, ...], unit: str = "rad") -> List[float]:  # pragma: no cover
+    ...
+
+
+def getunit(
+    v: Union[float, NDArray, Tuple[float, ...], List[float]], unit: str = "rad"
+) -> Union[float, NDArray, List[float]]:
     """
     Convert value according to angular units
 
@@ -465,6 +553,8 @@ def getunit(v, unit="rad") -> ArrayLike:
     :rtype: list(m) or ndarray(m)
     :raises ValueError: argument is not a valid angular unit
 
+    The input can be a list or ndarray() and the output is the same type.
+
     .. runblock:: pycon
 
         >>> from spatialmath.base import getunit
@@ -476,17 +566,24 @@ def getunit(v, unit="rad") -> ArrayLike:
         >>> getunit(np.r_[90, 180], 'deg')
     """
     if unit == "rad":
-        return v
+        if isinstance(v, tuple):
+            return list(v)
+        else:
+            return v
     elif unit == "deg":
         if isinstance(v, np.ndarray) or np.isscalar(v):
-            return v * math.pi / 180
-        else:
+            return v * math.pi / 180  # type: ignore
+        elif isinstance(v, (list, tuple)):
             return [x * math.pi / 180 for x in v]
+        else:
+            raise ValueError("bad argument")
     else:
         raise ValueError("invalid angular units")
 
+    return ret
 
-def isnumberlist(x):
+
+def isnumberlist(x: Any) -> bool:
     """
     Test if argument is a list of scalars
 
@@ -513,7 +610,7 @@ def isnumberlist(x):
     )
 
 
-def isvectorlist(x, n):
+def isvectorlist(x: Any, n: int) -> bool:
     """
     Test if argument is a list of vectors
 
@@ -536,7 +633,7 @@ def isvectorlist(x, n):
     return islistof(x, lambda x: isinstance(x, np.ndarray) and x.shape == (n,))
 
 
-def islistof(value, what, n=None):
+def islistof(value: Any, what: Union[Type, Callable], n: Optional[int] = None):
     """
     Test if argument is a list of specified type
 
